intelmq.bots.parsers.openphish package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.parsers.openphish package

## Submodules

## intelmq.bots.parsers.openphish.parser module

intelmq.bots.parsers.openphish.parser.BOT

  alias of `intelmq.bots.parsers.openphish.parser.OpenPhishParserBot`

class intelmq.bots.parsers.openphish.parser.OpenPhishParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse the OpenPhish feed

  process()

## intelmq.bots.parsers.openphish.parser_commercial module

intelmq.bots.parsers.openphish.parser_commercial.BOT

  alias of `intelmq.bots.parsers.openphish.parser_commercial.OpenPhishCommercialParserBot`

class intelmq.bots.parsers.openphish.parser_commercial.OpenPhishCommercialParserBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse the OpenPhish feed

  process()

## Module contents